import React from "react"
import styled from "styled-components"
import { Paragraph, Link } from "buoy-text"
import { responsive, colors, fontSize } from "buoy-theme"
import { getAbsoluteUrl } from "buoy-config"
import { FormattedMessage } from "react-intl/dist"

const date = new Date()
const currentYear = date.getFullYear()

const LegalLinks = styled(Paragraph)`
  ${fontSize("bodySmall")}
  margin: 14px 0 0 0;
`

const CopyRight = styled.span`
  ${responsive("margin-right", "60px", "60px", "60px", "60px", "20px")};
`

const StyledLink = styled(Link)`
  ${fontSize("bodySmall")}
  ${responsive("margin-right", "20px", "20px", "20px", "20px", "15px")};
  &:hover {
    color: ${colors["neutralDark"]};
  }
`

const StyledParagraph = styled(Paragraph)`
  ${fontSize("bodySmall")}
  margin-top: 14px;
`

const Copyright = ({ links, baseUrl }) => (
  <React.Fragment>
    <LegalLinks color="neutral">
      <CopyRight>&copy; Buoy Health, Inc. {currentYear}</CopyRight>
      {links.map(link => (
        <StyledLink
          key={link.text}
          color="neutral"
          underline={false}
          href={getAbsoluteUrl(link.href, baseUrl)}
        >
          {link.text === "Terms" ? (
            <FormattedMessage
              id="footer.legal.terms"
              defaultMessage={link.text}
            />
          ) : link.text === "Privacy" ? (
            <FormattedMessage
              id="footer.legal.terms"
              defaultMessage={link.text}
            />
          ) : link.text === "Cookies" ? (
            <FormattedMessage
              id="footer.legal.cookies"
              defaultMessage={link.text}
            />
          ) : link.text === "Editorial" ? (
            <FormattedMessage
              id="footer.legal.editorial"
              defaultMessage={link.text}
            />
          ) : (
            ""
          )}
        </StyledLink>
      ))}
    </LegalLinks>
    <StyledParagraph color="neutral" margin="0">
      <FormattedMessage
        id="footer.copyright"
        defaultMessage="The content available on buoyhealth.com is not a substitute for professional medical advice, diagnosis, or treatment."
      />
    </StyledParagraph>
  </React.Fragment>
)

export default Copyright
