import React from "react"
import styled from "styled-components"
import { Label, Link } from "buoy-text"
import { Ul, Li } from "buoy-list"
import { responsive, colors } from "buoy-theme"
import { getAbsoluteUrl } from "buoy-config"
import { FormattedMessage } from "react-intl/dist"
import Social from "./Social"

const Container = styled.div`
  display: flex;
  flex-wrap: wrap;
  min-width: 54%;
  ${responsive(
    "justify-content",
    "space-between",
    "space-between",
    "space-between",
    "space-between",
    "normal"
  )};
`

const Header = styled(Label)`
  margin: 0 0 8px 0;
  display: block;
  ${responsive("margin-bottom", "18px", "18px", "18px", "18px", "12px")};
`

const GroupContainer = styled.div`
  width: 144px;
  ${responsive("margin-bottom", "80px", "40px", "40px", "40px", "29px")};
`

const List = styled(Ul)`
  list-style: none;
  margin: 0;
  padding: 0;
`

const ListItem = styled(Li)`
  margin-bottom: 8px;
`

const StyledLink = styled(Link)`
  &:hover {
    color: ${colors["neutral"]};
  }
`

const Group = ({ heading, links, baseUrl }) => (
  <GroupContainer>
    <Header color="neutral">
      {heading === "Company" ? (
        <FormattedMessage id="footer.header.company" defaultMessage={heading} />
      ) : heading === "Read more" ? (
        <FormattedMessage
          id="footer.header.readmore"
          defaultMessage={heading}
        />
      ) : heading === "Resources" ? (
        <FormattedMessage
          id="footer.header.resources"
          defaultMessage={heading}
        />
      ) : (
        ""
      )}
    </Header>
    <List>
      {links.map(link => (
        <ListItem key={link.text}>
          <StyledLink
            color="neutralLightest"
            underline={false}
            href={getAbsoluteUrl(link.href, baseUrl)}
          >
            {link.text === "Team" && (
              <FormattedMessage
                id="footer.links.team"
                defaultMessage={link.text}
              />
            )}
            {link.text === "Writers" && (
              <FormattedMessage
                id="footer.links.writers"
                defaultMessage={link.text}
              />
            )}
            {link.text === "Careers" && (
              <FormattedMessage
                id="footer.links.careers"
                defaultMessage={link.text}
              />
            )}
            {link.text === "Press" && (
              <FormattedMessage
                id="footer.links.press"
                defaultMessage={link.text}
              />
            )}
            {link.text === "Businesses" && (
              <FormattedMessage
                id="footer.links.employers"
                defaultMessage={link.text}
              />
            )}
            {link.text === "Symptoms A-Z" && (
              <FormattedMessage
                id="footer.links.symptomsaz"
                defaultMessage={link.text}
              />
            )}
            {link.text === "Diagnoses A-Z" && (
              <FormattedMessage
                id="footer.links.diagnosesaz"
                defaultMessage={link.text}
              />
            )}
            {link.text === "Blog" && (
              <FormattedMessage
                id="footer.links.blog"
                defaultMessage={link.text}
              />
            )}
            {link.text === "Support" && (
              <FormattedMessage
                id="footer.links.support"
                defaultMessage={link.text}
              />
            )}
            {link.text === "Contact" && (
              <FormattedMessage
                id="footer.links.contact"
                defaultMessage={link.text}
              />
            )}
          </StyledLink>
        </ListItem>
      ))}
    </List>
  </GroupContainer>
)

const Links = ({ content, baseUrl }) => (
  <Container>
    {content.map(({ heading, links }) => (
      <Group key={heading} heading={heading} links={links} baseUrl={baseUrl} />
    ))}
    <GroupContainer>
      <Header color="neutral">
        <FormattedMessage
          id="footer.header.follow"
          defaultMessage="Follow Us"
        />
      </Header>
      <Social />
    </GroupContainer>
  </Container>
)

export default Links
