import React from "react"
import styled from "styled-components"
import { responsive, colors } from "buoy-theme"
import { footerConfig, navConfig } from "buoy-config"
import Copyright from "./components/Copyright"
import Links from "./components/Links"
import Trust from "./components/Trust"

const Container = styled.div`
  background-color: ${props => colors[props.backgroundColor]};
  display: flex;
  justify-content: center;
  flex-wrap: wrap;
  ${responsive(
    "padding",
    "48px 20px 18px 20px",
    "48px 20px 18px 20px",
    "48px 20px 18px 20px",
    "48px 20px 18px 20px",
    "38px 16px 18px 16px"
  )};
`

const InnerContainer = styled.div`
  max-width: 1200px;
  margin: 0 auto;
  display: flex;
  justify-content: space-between;
  flex-wrap: wrap;
  width: 100%;
`

const LegalContainer = styled(Container)`
  ${responsive(
    "padding",
    "4px 16px 18px 16px",
    "4px 16px 18px 16px",
    "4px 16px 18px 16px",
    "4px 16px 18px 16px",
    "4px 16px 18px 16px"
  )};
`

const FooterWrapper = ({ baseUrl = navConfig.brands.default.baseUrl }) => (
  <footer>
    <Container>
      <InnerContainer>
        <Links content={footerConfig.groups} baseUrl={baseUrl} />
        <Trust />
      </InnerContainer>
    </Container>
    <LegalContainer backgroundColor="neutralDarkest">
      <InnerContainer>
        <Copyright links={footerConfig.legal} baseUrl={baseUrl} />
      </InnerContainer>
    </LegalContainer>
  </footer>
)

Container.defaultProps = {
  backgroundColor: "neutralDarker",
}

export default FooterWrapper
